// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef FCITX5QT6WIDGETSADDONS_VERSION_H
#define FCITX5QT6WIDGETSADDONS_VERSION_H

#define FCITX5QT6WIDGETSADDONS_VERSION_STRING "5.1.12"
#define FCITX5QT6WIDGETSADDONS_VERSION_MAJOR 5
#define FCITX5QT6WIDGETSADDONS_VERSION_MINOR 1
#define FCITX5QT6WIDGETSADDONS_VERSION_PATCH 12
#define FCITX5QT6WIDGETSADDONS_VERSION ((5<<16)|(1<<8)|(12))

#endif
